@@ -1,7 +1,7 @@
 
 '''
 Advanced Power Monitor
-2008-2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+2008-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
 Connects to bunch of dbus signals, monitors values change and emmits signal in case of update.
 '''
 
@@ -10,6 +10,8 @@ import dbus, dbus.service
 from dbus.mainloop.glib import DBusGMainLoop
 from advpowcommon.util.loader import ClassLoader
 from advpowcommon.util.device import device
+from advpowcommon.util.execn import *
+from advpowcommon.util.common import *
 
 class apm(dbus.service.Object):
 
@@ -142,7 +144,7 @@ class apm(dbus.service.Object):
   def __init_interfaces(self):
     for x in self.__ifaces_map:
       try:
-        self.__interfaces[x] = dbus.Interface(self.__bus.get_object(self.__ifaces_map[x][0], self.__ifaces_map[x][1]), self.__ifaces_map[x][2])
+        self.__interfaces[x] = dbus.Interface(self.__bus.get_object(self.__ifaces_map[x][0], self.__ifaces_map[x][1], introspect=False, follow_name_owner_changes=True), self.__ifaces_map[x][2])
       except Exception, e:
         self.__interfaces[x] = None
         self.__print_exception('__init_interfaces', str(e))
@@ -443,11 +445,11 @@ class apm(dbus.service.Object):
 #Key: device_mode
   @dbus.service.method(dbus_interface='ru.spirit.advanced_power_monitor.request')
   def home_key_pressed_long(self):
-    Shell.run_command_async('/usr/bin/dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_home_key_pressed_long_ind')
+    run_shell_command_async('/usr/bin/dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_home_key_pressed_long_ind')
 
   @dbus.service.method(dbus_interface='ru.spirit.advanced_power_monitor.request')
   def home_key_pressed(self):
-    Shell.run_command_async('/usr/bin/dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_home_key_pressed_ind')
+    run_shell_command_async('/usr/bin/dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_home_key_pressed_ind')
 
   @dbus.service.method(dbus_interface='ru.spirit.advanced_power_monitor.request')
   def switch_device_mode(self):
@@ -455,7 +457,7 @@ class apm(dbus.service.Object):
       c_mode = self.get_value('device_mode')
       mode = c_mode
       if c_mode == 'normal':
-        Shell.run_command_async('/usr/bin/dbus-send --system --dest=com.nokia.icd /com/nokia/icd_ui com.nokia.icd_ui.disconnect boolean:true')
+        run_shell_command_async('/usr/bin/dbus-send --system --dest=com.nokia.icd /com/nokia/icd_ui com.nokia.icd_ui.disconnect boolean:true')
         mode = 'flight'
       elif c_mode == 'flight':
         mode = 'normal'
@@ -481,14 +483,14 @@ class apm(dbus.service.Object):
   def reboot(self):
     try:
       if self.__wrappers['device_mode']['object']: self.__wrappers['device_mode']['object'].reboot()
-      else: Shell.run_command_async('/sbin/reboot -n')
+      else: run_shell_command_async('/sbin/reboot -n')
     except Exception, e: self.__print_exception('reboot', str(e))
 
   @dbus.service.method(dbus_interface='ru.spirit.advanced_power_monitor.request')
   def shutdown(self):
     try:
       if self.__wrappers['device_mode']['object']: self.__wrappers['device_mode']['object'].shutdown()
-      else: Shell.run_command_async('/sbin/shutdown -n')
+      else: run_shell_command_async('/sbin/shutdown -n')
     except Exception, e: self.__print_exception('shutdown', str(e))
 #end
 
