@@ -10,7 +10,7 @@ class DeviceModeDummy(AbstractDeviceMode):
 
   def pre_init(self):
     self.friendly_name = 'Dummy'
-    self.dep_packages = {'advanced-power-monitor': '0.5.1'}
+    self.depends['packages'] = {'advanced-power-monitor': '0.5.1'}
     self.interfaces_map = {}
     self.export_signals = {'device_mode': {},
                            'system_inactive': {}
